@@ -51,17 +51,6 @@
 
 #include "imageio_pvt.h"
 
-#ifdef USE_BOOST_REGEX
-#    include <boost/regex.hpp>
-using boost::regex;
-using boost::regex_replace;
-#else
-#    include <regex>
-using std::regex;
-using std::regex_replace;
-#endif
-
-
 
 OIIO_PLUGIN_NAMESPACE_BEGIN
 
@@ -250,7 +239,7 @@ private:
     // program!  Ick.  So to avoid this, we always push a pointer, which
     // we expect NOT to be altered, and if it is, it's a danger sign (plus
     // we didn't crash).
-    bool safe_tiffgetfield(const std::string& name, int tag, void* dest)
+    bool safe_tiffgetfield(string_view name, int tag, void* dest)
     {
         void* ptr = NULL;  // dummy -- expect it to stay NULL
         bool ok   = TIFFGetField(m_tif, tag, dest, &ptr);
@@ -453,7 +442,7 @@ tiff_input_imageio_create()
 // OIIO_EXPORT int tiff_imageio_version = OIIO_PLUGIN_VERSION; // it's in tiffoutput.cpp
 
 OIIO_EXPORT const char* tiff_input_extensions[]
-    = { "tiff", "tif", "tx", "env", "sm", "vsm", nullptr };
+    = { "tif", "tiff", "tx", "env", "sm", "vsm", nullptr };
 
 OIIO_PLUGIN_EXPORTS_END
 
@@ -933,7 +922,8 @@ TIFFInput::readspec(bool read_meta)
     if (const char* compressname = tiff_compression_name(m_compression))
         m_spec.attribute("compression", compressname);
     m_predictor = PREDICTOR_NONE;
-    TIFFGetField(m_tif, TIFFTAG_PREDICTOR, &m_predictor);
+    if (!safe_tiffgetfield("Predictor", TIFFTAG_PREDICTOR, &m_predictor))
+        m_predictor = PREDICTOR_NONE;
 
     m_rowsperstrip = -1;
     if (!m_spec.tile_width) {
@@ -1141,49 +1131,31 @@ TIFFInput::readspec(bool read_meta)
         m_spec.erase_attribute("IPTC:Caption");
 
     // Because TIFF doesn't support arbitrary metadata, we look for certain
-    // hints in the ImageDescription and turn them into metadata.
+    // hints in the ImageDescription and turn them into metadata, also
+    // removing them from the ImageDescrption.
     bool updatedDesc = false;
-    static const char* fp_number_pattern
-        = "([+-]?((?:(?:[[:digit:]]*\\.)?[[:digit:]]+(?:[eE][+-]?[[:digit:]]+)?)))";
-    size_t found;
-    found = desc.rfind("oiio:ConstantColor=");
-    if (found != std::string::npos) {
-        size_t begin  = desc.find_first_of('=', found) + 1;
-        size_t end    = std::min(desc.find_first_of(' ', begin), desc.size());
-        string_view s = string_view(desc.data() + begin, end - begin);
-        m_spec.attribute("oiio:ConstantColor", s);
-        const std::string constcolor_pattern
-            = std::string("oiio:ConstantColor=(\\[?") + fp_number_pattern
-              + ",?)+\\]?[ ]*";
-        desc        = regex_replace(desc, regex(constcolor_pattern), "");
+    auto cc = Strutil::excise_string_after_head(desc, "oiio:ConstantColor=");
+    if (cc.size()) {
+        m_spec.attribute("oiio:ConstantColor", cc);
         updatedDesc = true;
     }
-    found = desc.rfind("oiio:AverageColor=");
-    if (found != std::string::npos) {
-        size_t begin  = desc.find_first_of('=', found) + 1;
-        size_t end    = std::min(desc.find_first_of(' ', begin), desc.size());
-        string_view s = string_view(desc.data() + begin, end - begin);
-        m_spec.attribute("oiio:AverageColor", s);
-        const std::string average_pattern
-            = std::string("oiio:AverageColor=(\\[?") + fp_number_pattern
-              + ",?)+\\]?[ ]*";
-        desc        = regex_replace(desc, regex(average_pattern), "");
+    auto ac = Strutil::excise_string_after_head(desc, "oiio:AverageColor=");
+    if (ac.size()) {
+        m_spec.attribute("oiio:AverageColor", ac);
         updatedDesc = true;
     }
-    found = desc.rfind("oiio:SHA-1=");
-    if (found == std::string::npos)  // back compatibility with < 1.5
-        found = desc.rfind("SHA-1=");
-    if (found != std::string::npos) {
-        size_t begin  = desc.find_first_of('=', found) + 1;
-        size_t end    = std::min(begin + 40, desc.size());
-        string_view s = string_view(desc.data() + begin, end - begin);
-        m_spec.attribute("oiio:SHA-1", s);
-        desc = regex_replace(desc, regex("oiio:SHA-1=[[:xdigit:]]*[ ]*"), "");
-        desc = regex_replace(desc, regex("SHA-1=[[:xdigit:]]*[ ]*"), "");
+    std::string sha = Strutil::excise_string_after_head(desc, "oiio:SHA-1=");
+    if (sha.empty())  // back compatibility with OIIO < 1.5
+        sha = Strutil::excise_string_after_head(desc, "SHA-1=");
+    if (sha.size()) {
+        m_spec.attribute("oiio:SHA-1", sha);
         updatedDesc = true;
     }
+
     if (updatedDesc) {
-        if (desc.size())
+        string_view d(desc);
+        Strutil::skip_whitespace(d);  // erase if it's only whitespace
+        if (d.size())
             m_spec.attribute("ImageDescription", desc);
         else
             m_spec.erase_attribute("ImageDescription");
